@@ -4,24 +4,29 @@ Define Errand context
 
 """
 
-import time, inspect
+import time, inspect, shutil, tempfile
 from numpy import ndarray, asarray
 
 from errand.order import Order
-from errand.engine import select_engine
 from errand.gofers import Gofers
 from errand.workshop import Workshop
 
 from errand.util import errand_builtins
 
+# TODO: supports eval, attributes in order
+# TODO: supports compiler hierachies with compiler wrappers
 
-class Context(object):
-    """Context class: provides consistent interface of Errand
 
+class Errand(object):
+    """Errand class
+
+* Out of context, OS-related tasks here
 """
 
-    def __init__(self, order, workdir, engine=None, context=None, timeout=None):
+    def __init__(self, order, timeout=None):
 
+        self.tempdir = None
+ 
         # TODO: config data
         # TODO: documentation
         # TODO: examples
@@ -35,22 +40,31 @@ class Context(object):
         # TODO: testing support
         # TODO: optimization support
         # TODO: documentation support
-        # TODO: plugin engines
-        # TODO: registry for engines, orders, sharedlibs, etc.
+        # TODO: plugin backend
+        # TODO: registry for backends, orders, sharedlibs, etc.
         # TODO: order template generation for informing mapping from teams/gofers to language specfic interpretation, and data movements, and shared/private variables, ...
         # TODO: basic approaches: user focuses on computation. clear/simple/reasonable role of Errand
 
         self._env = dict(errand_builtins)
-        self.tasks = {} # contains workshops
+        self.workshops = {} # contains workshops
         self.result = [] # contains results from workshops
 
         self.order = order if isinstance(order, Order) else Order(order, self._env)
 
-        self.workdir = workdir
-        self.engines = [e(workdir) for e in select_engine(engine, self.order)]
-        self.context = context
         self.timeout = timeout
+     
+    def __enter__(self):
 
+        self.tempdir = tempfile.mkdtemp()
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+
+        for ws in self.workshops:
+            self.result.append(ws.close(timeout=self.timeout))
+
+        if self.tempdir:
+            shutil.rmtree(self.tempdir)
 
     def gofers(self, *vargs):
 
@@ -116,20 +130,7 @@ class Context(object):
 
         inargs, outargs = self._split_arguments(vargs, caller_args)
 
-        engines = [e for e in self.engines if e.isavail()]
+        ws = Workshop(inargs, outargs, self.order, self.tempdir, **kwargs)
+        self.workshops[ws] = {}
 
-        if engines:
-            ws = Workshop(inargs, outargs, self.order, engines,
-                            self.workdir, **kwargs)
-            self.tasks[ws] = {}
-
-            return ws
-
-        else:
-            raise Exception("No engine is available")
-
-
-    def shutdown(self):
-
-        for ws in self.tasks:
-            self.result.append(ws.close(timeout=self.timeout))
+        return ws
