@@ -1,4 +1,4 @@
-"""Errand Pthread engine module
+"""Errand Pthread backend module
 
 
 """
@@ -6,7 +6,7 @@
 import os
 import numpy
 
-from errand.engine import Engine, varclass_template
+from errand.backend import CppBackendBase, varclass_template
 from errand.compiler import Compilers
 from errand.system import select_system
 from errand.util import which
@@ -76,6 +76,8 @@ void * _kernel(void * ptr){{
     {body}
 
     args->state = 2;
+
+    return NULL;
 }}
 """
 
@@ -92,6 +94,8 @@ void * _join(void * ptr){{
     }}
 
     isfinished = 1;
+
+    return NULL;
 }}
 """
 
@@ -128,18 +132,18 @@ calldevmain_template = """
 
 """
 
-class PThreadEngine(Engine):
+class PThreadBackend(CppBackendBase):
 
     name = "pthread"
     codeext = "cpp"
     libext = "so"
 
-    def __init__(self, workdir):
+    def __init__(self, workdir, compile):
 
-        compilers = Compilers(self.name)
+        compilers = Compilers(self.name, compile)
         targetsystem = select_system("cpu")
 
-        super(PThreadEngine, self).__init__(workdir, compilers,
+        super(PThreadBackend, self).__init__(workdir, compilers,
             targetsystem)
 
     #def compiler_option(self):
